@@ -27,4 +27,9 @@
 
 #undef LIBMCRYPT22
 #undef LIBMCRYPT24
+
+#undef NO_SIZE_T
+#undef NO_TIME_T
+
+#undef DEFINE_SIZE_T
  
\ No newline at end of file
