@@ -5,8 +5,8 @@ typedef struct {
 	int dh_bits;
 } ANON_SERVER_CREDENTIALS_INT;
 
-#define ANON_SERVER_CREDENTIALS ANON_SERVER_CREDENTIALS_INT*
-#define ANON_CLIENT_CREDENTIALS ANON_SERVER_CREDENTIALS_INT*
+#define GNUTLS_ANON_SERVER_CREDENTIALS ANON_SERVER_CREDENTIALS_INT*
+#define GNUTLS_ANON_CLIENT_CREDENTIALS ANON_SERVER_CREDENTIALS_INT*
 
 typedef struct ANON_CLIENT_AUTH_INFO_INT {
 	int dh_bits;
