@@ -141,7 +141,7 @@ int gen_srp_server_hello(GNUTLS_STATE state, opaque ** data)
 
 	/* firstly copy the algorithm used to generate the verifier 
 	 */
-	memcpy( data_g, &pwd_algo, 1);
+	data_g[0] = pwd_algo;
 
 	/* copy G (generator) to data */
 
@@ -246,7 +246,7 @@ int gen_srp_client_kx0(GNUTLS_STATE state, opaque ** data)
 	uint8 *data_a;
 	char *username;
 	char *password;
-	const SRP_CLIENT_CREDENTIALS cred =
+	const GNUTLS_SRP_CLIENT_CREDENTIALS cred =
 	    _gnutls_get_cred(state->gnutls_key, GNUTLS_SRP, NULL);
 
 	if (cred == NULL) {
@@ -306,7 +306,7 @@ int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size
 	opaque hd[SRP_MAX_HASH_SIZE];
 	char *username;
 	char *password;
-	const SRP_CLIENT_CREDENTIALS cred =
+	const GNUTLS_SRP_CLIENT_CREDENTIALS cred =
 	    _gnutls_get_cred(state->gnutls_key, GNUTLS_SRP, NULL);
 
 	if (cred == NULL) {
@@ -324,7 +324,7 @@ int proc_srp_server_hello(GNUTLS_STATE state, const opaque * data, int data_size
 	
 	i = 0;
 	DECR_LEN( data_size, 1);
-	memcpy( &pwd_algo, data, 1);
+	pwd_algo = data[0];
 	i++;
 
 	DECR_LEN( data_size, 2);
