@@ -5,14 +5,14 @@ typedef struct {
 	char* password;
 } SRP_CLIENT_CREDENTIALS_INT;
 
-#define SRP_CLIENT_CREDENTIALS SRP_CLIENT_CREDENTIALS_INT*
+#define GNUTLS_SRP_CLIENT_CREDENTIALS SRP_CLIENT_CREDENTIALS_INT*
 
 typedef struct {
 	char* password_file;
 	char* password_conf_file;
 } SRP_SERVER_CREDENTIALS_INT;
 
-#define SRP_SERVER_CREDENTIALS SRP_SERVER_CREDENTIALS_INT*
+#define GNUTLS_SRP_SERVER_CREDENTIALS SRP_SERVER_CREDENTIALS_INT*
 
 /* these structures should not use allocated data */
 typedef struct SRP_SERVER_AUTH_INFO_INT {
