@@ -144,7 +144,7 @@ int _gnutls_sbase64_encode(uint8 * data, int data_size, uint8 ** result)
 
 	ret += (data_size * 4) / 3;
 
-	(*result) = gnutls_malloc( ret + 1);
+	(*result) = gnutls_calloc( 1, ret + 1);
 	if ((*result) == NULL)
 		return -1;
 
@@ -171,7 +171,6 @@ int _gnutls_sbase64_encode(uint8 * data, int data_size, uint8 ** result)
 			return tmp;
 		}
 		memcpy(&(*result)[j], tmpres, tmp);
-		(*result)[j+tmp] = 0;
 	}
 
 	return strlen(*result);
