@@ -36,7 +36,7 @@ char *crypt_srpsha1(const char *username, const char *passwd,
 	int salt_size = strlen(salt);
 	unsigned char *local_salt, *v;
 	int passwd_len;
-	GNUTLS_MAC_HANDLE h1;
+	GNUTLS_HASH_HANDLE h1;
 	int vsize, hash_len = gnutls_hash_get_algo_len(GNUTLS_MAC_SHA);
 	opaque *tmp;
 	uint8 *rtext, *csalt;
