@@ -24,6 +24,7 @@
 #include "gnutls_auth_int.h"
 #include "gnutls_algorithms.h"
 #include "auth_x509.h"
+#include <gnutls_datum.h>
 
 #include "auth_anon.h"
 /* The functions here are used in order for authentication algorithms
@@ -211,7 +212,7 @@ void _gnutls_free_auth_info( GNUTLS_STATE state) {
 
 			if (info==NULL) break;
 			for (i=0;i<info->ncerts;i++) {
-				gnutls_free( info->raw_certificate_list[0].data);
+				gnutls_free_datum( &info->raw_certificate_list[i]);
 			}
 	
 			gnutls_free( info->raw_certificate_list);
