@@ -68,6 +68,8 @@ static void dlog( const char* str) {
 #endif
 }
 
+static int _gnutls_init = 0;
+
 /**
   * gnutls_global_init - This function initializes the global state to defaults.
   *
@@ -82,6 +84,12 @@ int gnutls_global_init( void)
 {
 	int result;
 
+	_gnutls_init++;
+
+	if (_gnutls_init!=1) {
+		return 0;
+	}
+
 	/* for gcrypt in order to be able to allocate memory */
 	gcry_set_allocation_handler(gnutls_malloc, gnutls_secure_malloc, _gnutls_is_secure_memory, gnutls_realloc, gnutls_free);
 
@@ -123,10 +131,14 @@ int gnutls_global_init( void)
 
 void gnutls_global_deinit( void) {
 
-	asn1_delete_structure( PKCS1_ASN);
-	asn1_delete_structure( PKIX1_ASN);
+	_gnutls_init--;
+
+	if (_gnutls_init==0) {
+		asn1_delete_structure( PKCS1_ASN);
+		asn1_delete_structure( PKIX1_ASN);
 	
-	_gnutls_dh_clear_mpis();
+		_gnutls_dh_clear_mpis();
+	}
 	
 }
 
