@@ -147,8 +147,8 @@ typedef enum Extensions { GNUTLS_EXTENSION_DNSNAME=0, GNUTLS_EXTENSION_MAX_RECOR
 typedef enum KXAlgorithm { GNUTLS_KX_X509PKI_RSA=1, GNUTLS_KX_X509PKI_DHE_DSS, GNUTLS_KX_X509PKI_DHE_RSA, GNUTLS_KX_ANON_DH, GNUTLS_KX_SRP } KXAlgorithm;
 typedef enum CredType { GNUTLS_X509PKI=1, GNUTLS_ANON, GNUTLS_SRP } CredType;
 typedef enum CipherType { CIPHER_STREAM, CIPHER_BLOCK } CipherType;
-typedef enum MACAlgorithm { GNUTLS_MAC_NULL=1, GNUTLS_MAC_MD5, GNUTLS_MAC_SHA } MACAlgorithm;
 typedef enum CompressionMethod { GNUTLS_COMP_NULL=1, GNUTLS_COMP_ZLIB } CompressionMethod;
+typedef enum MACAlgorithm { GNUTLS_MAC_NULL=1, GNUTLS_MAC_MD5, GNUTLS_MAC_SHA } MACAlgorithm;
 
 typedef enum ValidSession { VALID_TRUE, VALID_FALSE } ValidSession;
 typedef enum ResumableSession { RESUME_TRUE, RESUME_FALSE } ResumableSession;
@@ -177,11 +177,6 @@ typedef struct {
 } AUTH_CRED;
 
 
-typedef struct {
-	uint8 major;
-	uint8 minor;
-} ProtocolVersion;
-
 struct GNUTLS_KEY_INT {
 	/* For DH KX */
 	gnutls_sdatum			key;
@@ -496,7 +491,6 @@ typedef struct GNUTLS_STATE_INT *GNUTLS_STATE;
 
 
 /* functions */
-int gnutls_send_alert( GNUTLS_STATE state, AlertLevel level, AlertDescription desc);
 int gnutls_PRF( opaque * secret, int secret_size, uint8 * label,
 		  int label_size, opaque * seed, int seed_size,
 		  int total_bytes, void* ret);
@@ -522,4 +516,11 @@ void _gnutls_free_auth_info( GNUTLS_STATE state);
         state->gnutls_internals.handshake_recv_buffer.size = 0; \
         state->gnutls_internals.handshake_send_buffer_prev_size = 0
 
+#define set_adv_version( state, major, minor) \
+	state->gnutls_internals.adv_version_major = major; \
+	state->gnutls_internals.adv_version_minor = minor
+
+void _gnutls_set_adv_version( GNUTLS_STATE, GNUTLS_Version);
+GNUTLS_Version _gnutls_get_adv_version( GNUTLS_STATE);
+
 #endif /* GNUTLS_INT_H */
