@@ -122,7 +122,7 @@ MPI _gnutls_calc_srp_u(MPI B)
 {
 	int b_size;
 	opaque *b_holder, hd[MAX_HASH_SIZE];
-	GNUTLS_MAC_HANDLE td;
+	GNUTLS_HASH_HANDLE td;
 	uint32 u;
 	MPI ret;
 
@@ -226,7 +226,7 @@ MPI _gnutls_calc_srp_A(MPI * a, MPI g, MPI n)
 int _gnutls_calc_srp_sha(char *username, char *password, opaque * salt,
 			   int salt_size, int *size, void* digest)
 {
-	GNUTLS_MAC_HANDLE td;
+	GNUTLS_HASH_HANDLE td;
 	opaque res[MAX_HASH_SIZE];
 
 	*size = 20;
