@@ -130,7 +130,7 @@ inline static int decode(uint8 * result, const uint8 * data)
 /* encodes data and puts the result into result (localy alocated)
  * The result_size is the return value
  */
-int _gnutls_base64_encode(uint8 * data, int data_size, uint8 ** result)
+int _gnutls_base64_encode(const uint8 * data, int data_size, uint8 ** result)
 {
 	int i, ret, tmp, j;
 	char tmpres[4];
