@@ -105,106 +105,6 @@ GNUTLS_STATE initialize_state()
 	return state;
 }
 
-
-void print_info(GNUTLS_STATE state)
-{
-	const char *tmp;
-	const gnutls_datum * cert_list;
-	unsigned char sesid[32];
-	int sesid_size, i;
-	gnutls_DN dn;
-	CredType cred;
-	CertificateStatus status;
-	int cert_list_size = 0;
-	
-	/* print session_id specific data */
-	gnutls_session_get_id( state, sesid, &sesid_size);
-	printf("\n- Session ID: ");
-	for(i=0;i<sesid_size;i++)
-		printf("%.2X", sesid[i]);
-	printf("\n");
-
-	/* we could also use the KX algorithm to distinguish the functions
-	 * to call, but this is easier.
-	 */
-	cred = gnutls_auth_get_type(state);
-
-	switch(cred) {
-		case GNUTLS_SRP:
-			/* print srp specific data */
-			printf("\n- User '%s' connected\n",
-			       gnutls_srp_server_get_username( state));
-			break;
-		case GNUTLS_ANON:
-			printf("\n- Anonymous DH using prime of %d bits\n",
-			        gnutls_anon_server_get_dh_bits( state));
-			break;
-
-		case GNUTLS_X509PKI: 
-			cert_list = gnutls_x509pki_server_get_peer_certificate_list( state, &cert_list_size);
-			status = gnutls_x509pki_server_get_peer_certificate_status( state);
-			
-			switch( status) {
-			case GNUTLS_CERT_NOT_TRUSTED:
-				printf("- Peer's X509 Certificate was NOT verified\n");
-				break;
-			case GNUTLS_CERT_EXPIRED:
-				printf("- Peer's X509 Certificate was verified but is expired\n");
-				break;
-			case GNUTLS_CERT_TRUSTED:
-				printf("- Peer's X509 Certificate was verified\n");
-				break;
-			case GNUTLS_CERT_NONE:
-				printf("- Peer did not send any certificate.\n");
-				break;
-			case GNUTLS_CERT_INVALID:
-				printf("- Peer's X509 Certificate was invalid\n");
-				break;
-			}
-		
-			if (gnutls_kx_get_algo(state) == GNUTLS_KX_X509PKI_DHE_RSA || gnutls_kx_get_algo(state) == GNUTLS_KX_X509PKI_DHE_DSS) {
-				printf("\n- Ephemeral DH using prime of %d bits\n",
-			        gnutls_x509pki_server_get_dh_bits( state));
-			}
-
-			if (cert_list_size > 0) {
-				printf(" - Certificate info:\n");
-				printf(" - Certificate version: #%d\n", gnutls_x509pki_extract_certificate_version( &cert_list[0]));
-
-				if ( gnutls_x509pki_extract_certificate_dn( &cert_list[0], &dn) >= 0) {
-					PRINT_DN( dn);
-				}
-				
-				if (gnutls_x509pki_extract_certificate_issuer_dn( &cert_list[0], &dn) >= 0) {
-					printf(" - Certificate Issuer's info:\n");
-					PRINT_DN( dn);
-				}
-			}
-	}
-
-
-	/* print state information */
-
-	tmp = gnutls_protocol_get_name( gnutls_protocol_get_version(state));
-	printf("- Version: %s\n", tmp);
-
-	tmp = gnutls_kx_get_name(gnutls_kx_get_algo(state));
-	printf("- Key Exchange: %s\n", tmp);
-
-	tmp =
-	    gnutls_compression_get_name
-	    (gnutls_compression_get_algo(state));
-	printf("- Compression: %s\n", tmp);
-
-	tmp = gnutls_cipher_get_name(gnutls_cipher_get_algo(state));
-	printf("- Cipher: %s\n", tmp);
-
-	tmp = gnutls_mac_get_name(gnutls_mac_get_algo(state));
-	printf("- MAC: %s\n", tmp);
-
-
-}
-
 /* Creates html with the current state information.
  */
 #define tmp2 &http_buffer[strlen(http_buffer)]
